@@ -24,8 +24,8 @@ source $HOME/.cargo/env
 export CARGO_INCREMENTAL=0
 
 # Run test if indicated to do so.
-if [[ -z ${RUN_TESTS} ]]; then
-  cargo test -p openlineage_sql_python --no-default-features
+if [[ $RUN_TESTS = true ]]; then
+  cargo test --no-default-features
 fi
 
 # Build release wheels
